summaryrefslogtreecommitdiffstats
path: root/examples/dbus/dbus-chat/chat_interface.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/dbus/dbus-chat/chat_interface.h')
-rw-r--r--examples/dbus/dbus-chat/chat_interface.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/dbus/dbus-chat/chat_interface.h b/examples/dbus/dbus-chat/chat_interface.h
index 3ef00df2d4..ee01a79e4c 100644
--- a/examples/dbus/dbus-chat/chat_interface.h
+++ b/examples/dbus/dbus-chat/chat_interface.h
@@ -38,7 +38,7 @@
**
**
** This file was generated by qdbusxml2cpp version 0.7
** Command line was: qdbusxml2cpp -p chat_interface.h: com.trolltech.chat.xml
**
** qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
**
@@ -60,14 +60,14 @@
#include <QtDBus/QtDBus>
/*
* Proxy class for interface com.trolltech.chat
*/
class ComTrolltechChatInterface: public QDBusAbstractInterface
{
Q_OBJECT
public:
static inline const char *staticInterfaceName()
- { return "com.trolltech.chat"; }
+ { return "org.example.chat"; }
public:
ComTrolltechChatInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = 0);
@@ -38,7 +38,7 @@
**
** This file was generated by qdbusxml2cpp version 0.7
-** Command line was: qdbusxml2cpp -p chat_interface.h: com.trolltech.chat.xml
+** Command line was: qdbusxml2cpp -p chat_interface.h: org.example.chat.xml
**
** qdbusxml2cpp is Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
@@ -60,14 +60,14 @@
#include <QtDBus/QtDBus>
/*
- * Proxy class for interface com.trolltech.chat
+ * Proxy class for interface org.example.chat
*/
class ComTrolltechChatInterface: public QDBusAbstractInterface